@@ -29,7 +29,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <kurl.h>
 
 class KFileItem;
-class KFileItemList;
 class QDragEnterEvent;
 class QDragMoveEvent;
 class QDropEvent;
@@ -37,9 +36,10 @@ class QPixmap;
 
 namespace Gwenview {
 
+class AbstractDocumentInfoProvider;
 class AbstractThumbnailViewHelper;
 
-class ThumbnailViewPrivate;
+struct ThumbnailViewPrivate;
 class GWENVIEWLIB_EXPORT ThumbnailView : public QListView {
 	Q_OBJECT
 public:
@@ -50,12 +50,16 @@ public:
 
 	AbstractThumbnailViewHelper* thumbnailViewHelper() const;
 
+	void setDocumentInfoProvider(AbstractDocumentInfoProvider* provider);
+
+	AbstractDocumentInfoProvider* documentInfoProvider() const;
+
 	/**
 	 * Returns the thumbnail size.
 	 */
 	int thumbnailSize() const;
 
-	QPixmap thumbnailForIndex(const QModelIndex&);
+	QPixmap thumbnailForIndex(const QModelIndex&, QSize* fullSize = 0);
 
 	/**
 	 * Returns true if the document pointed by the index has been modified
@@ -64,9 +68,10 @@ public:
 	bool isModified(const QModelIndex&) const;
 
 	/**
-	 * Generate thumbnail for @a index.
+	 * Returns true if the document pointed by the index is currently busy
+	 * (loading, saving, rotating...)
 	 */
-	void generateThumbnailForIndex(const QModelIndex& index);
+	bool isBusy(const QModelIndex& index) const;
 
 	virtual void setModel(QAbstractItemModel* model);
 
@@ -75,6 +80,11 @@ public:
 	 */
 	using QListView::scheduleDelayedItemsLayout;
 
+	/**
+	 * Returns the current pixmap to paint when drawing a busy index.
+	 */
+	QPixmap busySequenceCurrentPixmap() const;
+
 Q_SIGNALS:
 	/**
 	 * It seems we can't use the 'activated()' signal for now because it does
@@ -124,10 +134,15 @@ protected:
 
 	virtual void showEvent(QShowEvent*);
 
+	virtual void wheelEvent(QWheelEvent*);
+
+	virtual void startDrag(Qt::DropActions);
+
 protected Q_SLOTS:
 	virtual void rowsAboutToBeRemoved(const QModelIndex& parent, int start, int end);
 	virtual void rowsInserted(const QModelIndex& parent, int start, int end);
 	virtual void selectionChanged(const QItemSelection& selected, const QItemSelection& deselected);
+	virtual void dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight);
 
 private Q_SLOTS:
 	void showContextMenu();
@@ -135,11 +150,26 @@ private Q_SLOTS:
 	void setThumbnail(const KFileItem&, const QPixmap&, const QSize&);
 	void setBrokenThumbnail(const KFileItem&);
 
+	/**
+	 * Generate thumbnail for @a index.
+	 */
+	void updateThumbnail(const QModelIndex& index);
+
+	/**
+	 * Tells the view the busy state of the document pointed by the index has changed.
+	 */
+	void updateThumbnailBusyState(const QModelIndex& index, bool);
+
+	/*
+	 * Cause a repaint of all busy indexes
+	 */
+	void updateBusyIndexes();
+
 	void generateThumbnailsForVisibleItems();
 	void smoothNextThumbnail();
 
 private:
-	friend class ThumbnailViewPrivate;
+	friend struct ThumbnailViewPrivate;
 	ThumbnailViewPrivate * const d;
 };
 
