@@ -6,8 +6,8 @@
  * Date        : 2006-12-09
  * Description : Raw decoding settings
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * Copyright (C) 2007-2008 by Guillaume Castagnino <casta at xwing dot info>
  *
  * This program is free software; you can redistribute it
@@ -31,6 +31,10 @@
 #include <QtCore/QString>
 #include <QtCore/QDebug>
 
+// KDE includes
+
+#include <kconfiggroup.h>
+
 // Local includes
 
 #include "libkdcraw_export.h"
@@ -118,6 +122,9 @@ public:
     /** Standard constructor with default settings */
     RawDecodingSettings();
 
+    /** Equivalent to the copy constructor */
+    RawDecodingSettings& operator=(const RawDecodingSettings& prm);  
+
     /** Compare for equality */
     bool operator==(const RawDecodingSettings &o) const;
 
@@ -127,8 +134,17 @@ public:
     /** Method to use a settings to optimize time loading, for exemple to compute image histogram */
     void optimizeTimeLoading();
 
+    /** Methods to read/write settings from/to a config file */
+    void readSettings(KConfigGroup& group);
+    void writeSettings(KConfigGroup& group);
+
 public:
 
+    /** If true, images with overblown channels are processed much more accurate, 
+        without 'pink clouds' (and blue highlights under tungsteen lamps).
+     */
+    bool fixColorsHighlights;
+
     /** If false, use a fixed white level, ignoring the image histogram.
     */
     bool autoBrightness;
@@ -203,7 +219,7 @@ public:
 
     /** Brightness of output image.
     */
-    float brightness;
+    double brightness;
 
     /** Set on the black point setting to decode RAW image.
     */
