@@ -245,9 +245,14 @@ bool KExiv2::loadFromData(const QByteArray& imgData) const
     {
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((Exiv2::byte*)imgData.data(), imgData.size());
 
-        d->filePath = QString();
+        d->filePath  = QString();
         image->readMetadata();
 
+        // Size and mimetype ---------------------------------
+
+        d->pixelSize = QSize(image->pixelWidth(), image->pixelHeight());
+        d->mimeType  = image->mimeType().c_str();
+
         // Image comments ---------------------------------
 
         d->imageComments() = image->comment();
@@ -270,7 +275,7 @@ bool KExiv2::loadFromData(const QByteArray& imgData) const
 
         return true;
     }
-    catch( Exiv2::Error &e )
+    catch( Exiv2::Error& e )
     {
         d->printExiv2ExceptionError("Cannot load metadata using Exiv2 ", e);
     }
@@ -295,6 +300,11 @@ bool KExiv2::load(const QString& filePath) const
         d->filePath = filePath;
         image->readMetadata();
 
+        // Size and mimetype ---------------------------------
+
+        d->pixelSize = QSize(image->pixelWidth(), image->pixelHeight());
+        d->mimeType  = image->mimeType().c_str();
+
         // Image comments ---------------------------------
 
         d->imageComments() = image->comment();
@@ -317,7 +327,7 @@ bool KExiv2::load(const QString& filePath) const
 
         return true;
     }
-    catch( Exiv2::Error &e )
+    catch( Exiv2::Error& e )
     {
         d->printExiv2ExceptionError("Cannot load metadata using Exiv2 ", e);
     }
@@ -505,7 +515,7 @@ bool KExiv2::save(const QString& filePath) const
 
         return true;
     }
-    catch( Exiv2::Error &e )
+    catch( Exiv2::Error& e )
     {
         d->printExiv2ExceptionError("Cannot save metadata using Exiv2 ", e);
     }
@@ -542,6 +552,16 @@ QString KExiv2::getFilePath() const
     return d->filePath;
 }
 
+QSize KExiv2::getPixelSize() const
+{
+    return d->pixelSize;
+}
+
+QString KExiv2::getMimeType() const
+{
+    return d->mimeType;
+}
+
 void KExiv2::setWriteRawFiles(bool on)
 {
     d->writeRawFiles = on;
