@@ -6,8 +6,8 @@
  * Date        : 2006-09-15
  * Description : Exiv2 library interface for KDE
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * Exiv2: http://www.exiv2.org
  * Exif : http://www.exif.org/Exif2-2.PDF
@@ -38,12 +38,14 @@
 #include <QtGui/QImage>
 #include <QtCore/QDateTime>
 #include <QtCore/QMap>
+#include <QtCore/QSharedDataPointer>
 #include <QtCore/QStringList>
 #include <QtCore/QVariant>
 
 // Local includes.
 
 #include "libkexiv2_export.h"
+#include "kexiv2data.h"
 
 namespace KExiv2Iface
 {
@@ -80,8 +82,7 @@ public:
         ORIENTATION_ROT_270      = 8
     };
 
-    /** A map used by decodeExifMetadata() decodeIptcMetadata() methods
-        to store Tags Key and Tags Value. 
+    /** A map used to store Tags Key and Tags Value.
      */
     typedef QMap<QString, QString> MetaDataMap;
 
@@ -91,6 +92,13 @@ public:
      */
     typedef QMap<QString, QString> AltLangMap; 
 
+    /** A map used to store Tags Key and a list of Tags properties :
+        - name,
+        - title,
+        - description.
+     */
+    typedef QMap<QString, QStringList> TagsMap;
+
 public:
 
     /** Standard constructor.
@@ -101,6 +109,10 @@ public:
      */
     KExiv2(const KExiv2& metadata);
 
+    /** Constructor to load from parsed data
+     */
+    KExiv2(const KExiv2Data& data);
+
     /** Contructor to Load Metadata from image file.
      */
     KExiv2(const QString& filePath);
@@ -109,7 +121,7 @@ public:
      */
     virtual ~KExiv2();
 
-    /** Create a deep copy of container
+    /** Create a copy of container
      */
     KExiv2& operator=(const KExiv2& metadata);
 
@@ -149,20 +161,18 @@ public:
      */
     static QString version();
 
-    /** return true if metadata from file cannot be written by Exiv2.
-        This method is obosolete and will be removed.
-        Use canWriteComment(), canWriteExif(), canWriteIptc(), or canWriteXmp() instead.
-     */
-    KDE_DEPRECATED static bool isReadOnly(const QString& filePath);
-
     //-----------------------------------------------------------------
     //-- GENERAL methods ----------------------------------------------
     //-----------------------------------------------------------------
 
+    KExiv2Data data() const;
+    void setData(const KExiv2Data& data);
+
     /** Load all metadata (Exif, Iptc, Xmp, and JFIF Comments) from a byte array. 
         Return true if metadata have been loaded successfully from image data.
      */
-    bool load(const QByteArray& imgData) const;
+    bool loadFromData(const QByteArray& imgData) const;
+    KDE_DEPRECATED bool load(const QByteArray& imgData) const;
 
     /** Load all metadata (Exif, Iptc, Xmp, and JFIF Comments) from a picture (JPEG, RAW, TIFF, PNG,
         DNG, etc...). Return true if metadata have been loaded successfully from file.
@@ -191,6 +201,22 @@ public:
      */
     QString getFilePath() const;
 
+    /** Returns the pixel size of the current image. This information is read from the file,
+     *  not from the metadata. The returned QSize is valid if the KExiv2 object was _constructed_
+     *  by reading a file or image data; the information is not available when the object
+     *  was created from KExiv2Data.
+     *  Note that in the Exif or XMP metadata, there may be fields describing the image size.
+     *  These fields are not accessed by this method.
+     *  When replacing the metadata with setData(), the metadata may change; this information
+     *  always keeps referring to the file it was initially read from.
+     */
+    QSize getPixelSize() const;
+
+    /** Returns the mime type of this image. The information is read from the file;
+     *  see the docs for pixelSize() to know when it is available.
+     */
+    QString getMimeType() const;
+
     /** Enable or disable writing metadata operations to RAW tiff based files.
         It's require Exiv2 0.18. By default RAW files are untouched.
      */
@@ -316,12 +342,20 @@ public:
         header. Header is saved into 'lang'. If no language alternative is founf, value is returned 
         as well and 'lang' is set to a null string.
      */
-    static QString detectLanguageAlt(const QString &value, QString& lang);
+    static QString detectLanguageAlt(const QString& value, QString& lang);
 
     //-----------------------------------------------------------------
     //-- EXIF manipulation methods ------------------------------------
     //-----------------------------------------------------------------
 
+    /** Return a map of all standard Exif tags supported by Exiv2.
+     */
+    TagsMap getStdExifTagsList() const;
+
+    /** Return a map of all non-standard Exif tags (makernotes) supported by Exiv2.
+     */
+    TagsMap getMakernoteTagsList() const;
+
     /** Return 'true' if Exif can be written in file.
      */
     static bool canWriteExif(const QString& filePath);
@@ -334,11 +368,15 @@ public:
      */
     bool clearExif() const;
 
-    /** Return a Qt byte array copy of Exif container get from current image. 
-        Set true 'addExifHeader' parameter to add an Exif header to Exif metadata. 
-        Return a null Qt byte array if there is no Exif metadata in memory.
+    /** Returns the exif data encoded to a QByteArray in a form suitable
+        for storage in a JPEG image.
+        Note that this encoding is a lossy operation.
+
+        Set true 'addExifHeader' parameter to add an Exif header to Exif metadata.
+        Returns a null Qt byte array if there is no Exif metadata in memory.
      */
-    QByteArray getExif(bool addExifHeader=false) const;
+    KDE_DEPRECATED QByteArray getExif(bool addExifHeader=false) const;
+    QByteArray getExifEncoded(bool addExifHeader=false) const;
 
     /** Set the Exif data using a Qt byte array. Return true if Exif metadata
         have been changed in memory.
@@ -354,14 +392,20 @@ public:
     /** Fix orientation of a QImage image accordingly with Exif orientation tag.
         Return true if image is rotated, else false.
      */
-    bool rotateExifQImage(QImage &image, ImageOrientation orientation) const;
+    bool rotateExifQImage(QImage& image, ImageOrientation orientation) const;
 
     /** Set the Exif Thumbnail image. The thumbnail image must have the right dimensions before. 
         Look Exif specification for details. Return true if thumbnail have been changed in metadata.
      */
     bool setExifThumbnail(const QImage& thumb, bool setProgramName=true) const;
 
-    /** Return a QString copy of Exif user comments. Return a null string if user comments cannot 
+    /** Remove the Exif Thumbnail from the image */
+    bool removeExifThumbnail() const;
+
+    /** Adds a JPEG thumbnail to a TIFF images. Use this instead of setExifThumbnail for TIFF images. */
+    bool setTiffThumbnail(const QImage& thumb, bool setProgramName=true) const;
+
+    /** Return a QString copy of Exif user comments. Return a null string if user comments cannot
         be found.
      */
     QString getExifComment() const;
@@ -374,11 +418,11 @@ public:
     /** Get an Exif tags content like a string. If 'escapeCR' parameter is true, the CR characters
         will be removed. If Exif tag cannot be found a null string is returned.
      */
-    QString getExifTagString(const char *exifTagName, bool escapeCR=true) const;
+    QString getExifTagString(const char* exifTagName, bool escapeCR=true) const;
 
     /** Set an Exif tag content using a string. Return true if tag is set successfully.
      */
-    bool setExifTagString(const char *exifTagName, const QString& value, bool setProgramName=true) const;
+    bool setExifTagString(const char* exifTagName, const QString& value, bool setProgramName=true) const;
 
     /** Get an Exif tag content like a long value. Return true if Exif tag be found.
      */
@@ -386,28 +430,28 @@ public:
 
     /** Set an Exif tag content using a long value. Return true if tag is set successfully.
      */
-    bool setExifTagLong(const char *exifTagName, long val, bool setProgramName=true) const;
+    bool setExifTagLong(const char* exifTagName, long val, bool setProgramName=true) const;
 
     /** Get the 'component' index of an Exif tags content like a rational value. 
         'num' and 'den' are the numerator and the denominator of the rational value. 
         Return true if Exif tag be found.
      */
-    bool getExifTagRational(const char *exifTagName, long int &num, long int &den, int component=0) const;
+    bool getExifTagRational(const char* exifTagName, long int& num, long int& den, int component=0) const;
 
     /** Set an Exif tag content using a rational value. 
         'num' and 'den' are the numerator and the denominator of the rational value. 
         Return true if tag is set successfully.
      */
-    bool setExifTagRational(const char *exifTagName, long int num, long int den, bool setProgramName=true) const;
+    bool setExifTagRational(const char* exifTagName, long int num, long int den, bool setProgramName=true) const;
 
     /** Get an Exif tag content like a bytes array. Return an empty bytes array if Exif 
         tag cannot be found.
      */
-    QByteArray getExifTagData(const char *exifTagName) const;
+    QByteArray getExifTagData(const char* exifTagName) const;
 
     /** Set an Exif tag content using a bytes array. Return true if tag is set successfully.
      */
-    bool setExifTagData(const char *exifTagName, const QByteArray& data, bool setProgramName=true) const;
+    bool setExifTagData(const char* exifTagName, const QByteArray& data, bool setProgramName=true) const;
 
     /** Get an Exif tags content as a QVariant. Returns a null QVariant if the Exif
         tag cannot be found.
@@ -417,7 +461,7 @@ public:
         if rationalAsListOfInts is true, as double if rationalAsListOfInts is false.
         An exif tag of numerical type may contain more than one value; set component to the desired index.
      */
-    QVariant getExifTagVariant(const char *exifTagName, bool rationalAsListOfInts=true, bool escapeCR=true, int component=0) const;
+    QVariant getExifTagVariant(const char* exifTagName, bool rationalAsListOfInts=true, bool escapeCR=true, int component=0) const;
 
     /** Set an Exif tag content using a QVariant. Returns true if tag is set successfully.
         All types described for the above method are supported.
@@ -425,28 +469,28 @@ public:
         For the meaning of rationalWantSmallDenominator, see the documentation of the convertToRational methods.
         Setting a value with multiple components is currently not supported.
      */
-    bool setExifTagVariant(const char *exifTagName, const QVariant& data,
+    bool setExifTagVariant(const char* exifTagName, const QVariant& data,
                            bool rationalWantSmallDenominator=true, bool setProgramName=true) const;
 
     /** Remove the Exif tag 'exifTagName' from Exif metadata. Return true if tag is 
         removed successfully or if no tag was present.
      */
-    bool removeExifTag(const char *exifTagName, bool setProgramName=true) const;
+    bool removeExifTag(const char* exifTagName, bool setProgramName=true) const;
 
     /** Return the Exif Tag title or a null string.
      */
-    QString getExifTagTitle(const char *exifTagName);
+    QString getExifTagTitle(const char* exifTagName);
 
     /** Return the Exif Tag description or a null string.
      */
-    QString getExifTagDescription(const char *exifTagName);
+    QString getExifTagDescription(const char* exifTagName);
 
     /** Takes a QVariant value as it could have been retrieved by getExifTagVariant with the given exifTagName,
         and returns its value properly converted to a string (including i18n).
         This is equivalent to calling getExifTagString directly.
         If escapeCR is true CR characters will be removed from the result.
      */
-    QString createExifUserStringFromValue(const char *exifTagName, const QVariant &val, bool escapeCR=true);
+    QString createExifUserStringFromValue(const char* exifTagName, const QVariant& val, bool escapeCR=true);
 
     /** Return a map of Exif tags name/value found in metadata sorted by 
         Exif keys given by 'exifKeysFilter'. 
@@ -466,12 +510,16 @@ public:
         - not include "Iop", or "Thumbnail", or "Image", or "Photo" in the Exif tag keys 
           if 'inverSelection' is true.
      */
-    KExiv2::MetaDataMap getExifTagsDataList(const QStringList &exifKeysFilter, bool invertSelection=false) const;
+    KExiv2::MetaDataMap getExifTagsDataList(const QStringList& exifKeysFilter, bool invertSelection=false) const;
 
     //-------------------------------------------------------------
     //-- IPTC manipulation methods --------------------------------
     //-------------------------------------------------------------
 
+    /** Return a map of all standard Iptc tags supported by Exiv2.
+     */
+    KExiv2::TagsMap getIptcTagsList() const;
+
     /** Return 'true' if Iptc can be written in file.
      */
     static bool canWriteIptc(const QString& filePath);
@@ -502,7 +550,7 @@ public:
 
     /** Set an Iptc tag content using a string. Return true if tag is set successfully.
      */
-    bool setIptcTagString(const char *iptcTagName, const QString& value, bool setProgramName=true) const;
+    bool setIptcTagString(const char* iptcTagName, const QString& value, bool setProgramName=true) const;
 
     /** Returns a strings list with of multiple Iptc tags from the image. Return an empty list if no tag is found. */
     /** Get the values of all IPTC tags with the given tag name in a string list.
@@ -523,24 +571,24 @@ public:
     /** Get an Iptc tag content as a bytes array. Return an empty bytes array if Iptc
         tag cannot be found.
      */
-    QByteArray getIptcTagData(const char *iptcTagName) const;
+    QByteArray getIptcTagData(const char* iptcTagName) const;
 
     /** Set an Iptc tag content using a bytes array. Return true if tag is set successfully.
      */
-    bool setIptcTagData(const char *iptcTagName, const QByteArray& data, bool setProgramName=true) const;
+    bool setIptcTagData(const char* iptcTagName, const QByteArray& data, bool setProgramName=true) const;
 
     /** Remove the all instance of Iptc tags 'iptcTagName' from Iptc metadata. Return true if all 
         tags have been removed successfully (or none were present).
      */
-    bool removeIptcTag(const char *iptcTagName, bool setProgramName=true) const;
+    bool removeIptcTag(const char* iptcTagName, bool setProgramName=true) const;
 
     /** Return the Iptc Tag title or a null string.
      */
-    QString getIptcTagTitle(const char *iptcTagName);
+    QString getIptcTagTitle(const char* iptcTagName);
 
     /** Return the Iptc Tag description or a null string.
      */
-    QString getIptcTagDescription(const char *iptcTagName);
+    QString getIptcTagDescription(const char* iptcTagName);
 
     /** Return a map of Iptc tags name/value found in metadata sorted by
         Iptc keys given by 'iptcKeysFilter'. 
@@ -558,7 +606,7 @@ public:
         - not include "Envelope", or "Application2" in the Iptc tag keys 
           if 'inverSelection' is true.
      */
-    KExiv2::MetaDataMap getIptcTagsDataList(const QStringList &iptcKeysFilter, bool invertSelection=false) const;
+    KExiv2::MetaDataMap getIptcTagsDataList(const QStringList& iptcKeysFilter, bool invertSelection=false) const;
 
     /** Return a strings list of Iptc keywords from image. Return an empty list if no keyword are set.
      */
@@ -601,6 +649,10 @@ public:
     //-- XMP manipulation methods --------------------------------
     //------------------------------------------------------------
 
+    /** Return a map of all standard Xmp tags supported by Exiv2.
+     */
+    KExiv2::TagsMap getXmpTagsList() const;
+
     /** Return 'true' if Xmp can be written in file.
      */
     static bool canWriteXmp(const QString& filePath);
@@ -630,15 +682,15 @@ public:
 
     /** Set a Xmp tag content using a string. Return true if tag is set successfully.
      */
-    bool setXmpTagString(const char *xmpTagName, const QString& value, bool setProgramName=true) const;
+    bool setXmpTagString(const char* xmpTagName, const QString& value, bool setProgramName=true) const;
 
     /** Return the Xmp Tag title or a null string.
      */
-    QString getXmpTagTitle(const char *xmpTagName);
+    QString getXmpTagTitle(const char* xmpTagName);
 
     /** Return the Xmp Tag description or a null string.
      */
-    QString getXmpTagDescription(const char *xmpTagName);
+    QString getXmpTagDescription(const char* xmpTagName);
 
     /** Return a map of Xmp tags name/value found in metadata sorted by 
         Xmp keys given by 'xmpKeysFilter'.
@@ -656,7 +708,7 @@ public:
         - not include "dc", or "xmp" in the Xmp tag keys 
           if 'inverSelection' is true.
      */
-    KExiv2::MetaDataMap getXmpTagsDataList(const QStringList &xmpKeysFilter, bool invertSelection=false) const;
+    KExiv2::MetaDataMap getXmpTagsDataList(const QStringList& xmpKeysFilter, bool invertSelection=false) const;
 
     /** Get all redondant Alternative Language Xmp tags content like a map. 
         See AltLangMap class description for details.
@@ -669,7 +721,7 @@ public:
         description for details. If tag already exist, it wil be removed before.
         Return true if tag is set successfully.
      */
-    bool setXmpTagStringListLangAlt(const char *xmpTagName, const KExiv2::AltLangMap& values,
+    bool setXmpTagStringListLangAlt(const char* xmpTagName, const KExiv2::AltLangMap& values,
                                     bool setProgramName) const;
 
     /** Get a Xmp tag content like a string set with an alternative language
@@ -684,7 +736,7 @@ public:
         set alternative language to default settings ("x-default").
         Return true if tag is set successfully.
      */
-    bool setXmpTagStringLangAlt(const char *xmpTagName, const QString& value, 
+    bool setXmpTagStringLangAlt(const char* xmpTagName, const QString& value, 
                                 const QString& langAlt, bool setProgramName=true) const;
 
     /** Get a Xmp tag content like a sequence of strings. If 'escapeCR' parameter is true, the CR characters
@@ -695,7 +747,7 @@ public:
     /** Set a Xmp tag content using the sequence of strings 'seq'.
         Return true if tag is set successfully.
      */
-    bool setXmpTagStringSeq(const char *xmpTagName, const QStringList& seq,
+    bool setXmpTagStringSeq(const char* xmpTagName, const QStringList& seq,
                             bool setProgramName=true) const;
 
     /** Get a Xmp tag content like a bag of strings. If 'escapeCR' parameter is true, the CR characters
@@ -706,9 +758,24 @@ public:
     /** Set a Xmp tag content using the bag of strings 'bag'.
         Return true if tag is set successfully.
      */
-    bool setXmpTagStringBag(const char *xmpTagName, const QStringList& bag,
+    bool setXmpTagStringBag(const char* xmpTagName, const QStringList& bag,
                             bool setProgramName=true) const;
 
+    /** Set an Xmp tag content using a list of strings defined by the 'entriesToAdd' parameter.
+        The existing entries are preserved. The method will compare
+        all new with all already existing entries to prevent duplicates in the image.
+        Return true if the entries have been added to metadata.
+     */
+    bool addToXmpTagStringBag(const char* xmpTagName, const QStringList& entriesToAdd,
+                              bool setProgramName) const;
+
+    /** Remove those Xmp tag entries that are listed in entriesToRemove from the entries in metadata.
+        Return true if tag entries are no longer contained in metadata.
+        All other entries are preserved.
+     */
+    bool removeFromXmpTagStringBag(const char* xmpTagName, const QStringList& entriesToRemove,
+                                   bool setProgramName) const;
+
     /** Get an Xmp tag content as a QVariant. Returns a null QVariant if the Xmp
         tag cannot be found.
         For string and integer values the matching QVariant types will be used,
@@ -719,7 +786,7 @@ public:
         LangAlt values will have type Map (QMap<QString, QVariant>) with the language
         code as key and the contents as value, of type String.
      */
-    QVariant getXmpTagVariant(const char *xmpTagName, bool rationalAsListOfInts=true, bool stringEscapeCR=true) const;
+    QVariant getXmpTagVariant(const char* xmpTagName, bool rationalAsListOfInts=true, bool stringEscapeCR=true) const;
 
     /** Return a strings list of Xmp keywords from image. Return an empty list if no keyword are set.
      */
@@ -732,6 +799,11 @@ public:
      */
     bool setXmpKeywords(const QStringList& newKeywords, bool setProgramName=true) const;
 
+    /** Remove those Xmp keywords that are listed in keywordsToRemove from the keywords in metadata.
+        Return true if keywords are no longer contained in metadata.
+     */
+    bool removeXmpKeywords(const QStringList& keywordsToRemove, bool setProgramName=true);
+
     /** Return a strings list of Xmp subjects from image. Return an empty list if no subject are set.
      */
     QStringList getXmpSubjects() const;
@@ -743,6 +815,11 @@ public:
      */
     bool setXmpSubjects(const QStringList& newSubjects, bool setProgramName=true) const;
 
+    /** Remove those Xmp subjects that are listed in subjectsToRemove from the subjects in metadata.
+        Return true if subjects are no longer contained in metadata.
+     */
+    bool removeXmpSubjects(const QStringList& subjectsToRemove, bool setProgramName=true);
+
     /** Return a strings list of Xmp sub-categories from image. Return an empty list if no sub-category 
         are set.
      */
@@ -755,18 +832,27 @@ public:
      */
     bool setXmpSubCategories(const QStringList& newSubCategories, bool setProgramName=true) const;
 
+    /** Remove those Xmp sub-categories that are listed in categoriesToRemove from the sub-categories in metadata.
+        Return true if subjects are no longer contained in metadata.
+     */
+    bool removeXmpSubCategories(const QStringList& categoriesToRemove, bool setProgramName=true);
+
+    /** Remove the Xmp tag 'xmpTagName' from Xmp metadata. Return true if tag is
+        removed successfully or if no tag was present.
+     */
+    bool removeXmpTag(const char* xmpTagName, bool setProgramName=true) const;
+
+
     /** Register a namespace which Exiv2 doesn't know yet. This is only needed
         when new Xmp properties are added manually. 'uri' is the namespace url and prefix the 
         string used to construct new Xmp key (ex. "Xmp.digiKam.tagList").
         NOTE: If the Xmp metadata is read from an image, namespaces are decoded and registered 
         by Exiv2 at the same time.
      */
-    bool registerXmpNameSpace(const QString& uri, const QString& prefix) const;
+    static bool registerXmpNameSpace(const QString& uri, const QString& prefix);
 
-    /** Remove the Xmp tag 'xmpTagName' from Xmp metadata. Return true if tag is 
-        removed successfully or if no tag was present.
-     */
-    bool removeXmpTag(const char *xmpTagName, bool setProgramName=true) const;
+    /** Unregister a previously registered custom namespace */
+    static bool unregisterXmpNameSpace(const QString& uri);
 
     //------------------------------------------------------------
     //-- GPS manipulation methods --------------------------------
@@ -786,12 +872,12 @@ public:
         where the sign determines the direction ref (North + / South - ; East + / West -).
         Returns true if the information is available.
     */
-    bool getGPSLatitudeNumber(double *latitude) const;
-    bool getGPSLongitudeNumber(double *longitude) const;
+    bool getGPSLatitudeNumber(double* latitude) const;
+    bool getGPSLongitudeNumber(double* longitude) const;
 
     /** Get GPS altitude information, in meters, relative to sea level (positive sign above sea level)
      */
-    bool getGPSAltitude(double *altitude) const;
+    bool getGPSAltitude(double* altitude) const;
 
     /** Set all GPS location information into image. Return true if all information have been 
         changed in metadata.
@@ -842,23 +928,23 @@ public:
         Returns true if the conversion was successful.
         If minutes is given in the fractional form, a denominator of 1000000 for the minutes will be used.
      */
-    static bool convertFromGPSCoordinateString(const QString &coordinate,
-                                               long int *numeratorDegrees, long int *denominatorDegrees,
-                                               long int *numeratorMinutes, long int *denominatorMinutes,
-                                               long int *numeratorSeconds, long int *denominatorSeconds,
-                                               char *directionReference);
+    static bool convertFromGPSCoordinateString(const QString& coordinate,
+                                               long int* numeratorDegrees, long int* denominatorDegrees,
+                                               long int* numeratorMinutes, long int* denominatorMinutes,
+                                               long int* numeratorSeconds, long int* denominatorSeconds,
+                                               char* directionReference);
 
     /** Convert a GPSCoordinate string as defined by XMP to a double floating point number in degrees
         where the sign determines the direction ref (North + / South - ; East + / West -).
         Returns true if the conversion was successful.
      */
-    static bool convertFromGPSCoordinateString(const QString &gpsString, double *coordinate);
+    static bool convertFromGPSCoordinateString(const QString& gpsString, double* coordinate);
 
     /** Converts a GPSCoordinate string to user presentable numbers, integer degrees and minutes and
         double floating point seconds, and a direction reference ('N' or 'S', 'E' or 'W')
      */
-    static bool convertToUserPresentableNumbers(const QString &coordinate,
-                                                int *degrees, int *minutes, double *seconds, char *directionReference);
+    static bool convertToUserPresentableNumbers(const QString& coordinate,
+                                                int* degrees, int* minutes, double* seconds, char* directionReference);
 
     /** Converts a double floating point number to user presentable numbers, integer degrees and minutes and
         double floating point seconds, and a direction reference ('N' or 'S', 'E' or 'W').
@@ -866,7 +952,7 @@ public:
         if the latitude or the longitude is meant by the double parameter.
      */
     static void convertToUserPresentableNumbers(bool isLatitude, double coordinate,
-                                                int *degrees, int *minutes, double *seconds, char *directionReference);
+                                                int* degrees, int* minutes, double* seconds, char* directionReference);
 
 protected:
 
