@@ -44,7 +44,7 @@ bool KExiv2::canWriteXmp(const QString& filePath)
     catch( Exiv2::Error& e )
     {
         std::string s(e.what());
-        kDebug(51003) << "Cannot check Xmp access mode using Exiv2 (Error #" 
+        kDebug(51003) << "Cannot check Xmp access mode using Exiv2 (Error #"
                       << e.code() << ": " << s.c_str() << ")" << endl;
     }
 
@@ -52,9 +52,11 @@ bool KExiv2::canWriteXmp(const QString& filePath)
 
 #else
 
-    return false;
+    Q_UNUSED(filePath);
 
 #endif // _XMP_SUPPORT_
+
+    return false;
 }
 
 bool KExiv2::hasXmp() const
@@ -142,6 +144,10 @@ bool KExiv2::setXmp(const QByteArray& data) const
         d->printExiv2ExceptionError("Cannot set Xmp data using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(data);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -229,6 +235,11 @@ KExiv2::MetaDataMap KExiv2::getXmpTagsDataList(const QStringList& xmpKeysFilter,
         d->printExiv2ExceptionError("Cannot parse Xmp metadata using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpKeysFilter);
+    Q_UNUSED(invertSelection);
+
 #endif // _XMP_SUPPORT_
 
     return MetaDataMap();
@@ -238,17 +249,21 @@ QString KExiv2::getXmpTagTitle(const char* xmpTagName)
 {
 #ifdef _XMP_SUPPORT_
 
-    try 
+    try
     {
         std::string xmpkey(xmpTagName);
         Exiv2::XmpKey xk(xmpkey);
         return QString::fromLocal8Bit( Exiv2::XmpProperties::propertyTitle(xk) );
     }
-    catch (Exiv2::Error& e) 
+    catch (Exiv2::Error& e)
     {
         d->printExiv2ExceptionError("Cannot get Xmp metadata tag title using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+
 #endif // _XMP_SUPPORT_
 
     return QString();
@@ -257,16 +272,22 @@ QString KExiv2::getXmpTagTitle(const char* xmpTagName)
 QString KExiv2::getXmpTagDescription(const char* xmpTagName)
 {
 #ifdef _XMP_SUPPORT_
-    try 
+
+    try
     {
         std::string xmpkey(xmpTagName);
         Exiv2::XmpKey xk(xmpkey);
         return QString::fromLocal8Bit( Exiv2::XmpProperties::propertyDesc(xk) );
     }
-    catch (Exiv2::Error& e) 
+    catch (Exiv2::Error& e)
     {
         d->printExiv2ExceptionError("Cannot get Xmp metadata tag description using Exiv2 ", e);
     }
+
+#else
+
+    Q_UNUSED(xmpTagName);
+
 #endif // _XMP_SUPPORT_
 
     return QString();
@@ -299,6 +320,11 @@ QString KExiv2::getXmpTagString(const char* xmpTagName, bool escapeCR) const
                                     .arg(xmpTagName), e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(escapeCR);
+
 #endif // _XMP_SUPPORT_
 
     return QString();
@@ -325,6 +351,12 @@ bool KExiv2::setXmpTagString(const char* xmpTagName, const QString& value, bool
         d->printExiv2ExceptionError("Cannot set Xmp tag string into image using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(value);
+    Q_UNUSED(setProgramName);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -345,8 +377,8 @@ KExiv2::AltLangMap KExiv2::getXmpTagStringListLangAlt(const char* xmpTagName, bo
                 AltLangMap map;
                 const Exiv2::LangAltValue &value = static_cast<const Exiv2::LangAltValue &>(it->value());
 
-                for (Exiv2::LangAltValue::ValueType::const_iterator it2 = value.value_.begin(); 
-                     it2 != value.value_.end(); ++it2) 
+                for (Exiv2::LangAltValue::ValueType::const_iterator it2 = value.value_.begin();
+                     it2 != value.value_.end(); ++it2)
                 {
                     QString lang = QString::fromUtf8(it2->first.c_str());
                     QString text = QString::fromUtf8(it2->second.c_str());
@@ -366,12 +398,17 @@ KExiv2::AltLangMap KExiv2::getXmpTagStringListLangAlt(const char* xmpTagName, bo
                                     .arg(xmpTagName), e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(escapeCR);
+
 #endif // _XMP_SUPPORT_
 
     return AltLangMap();
 }
 
-bool KExiv2::setXmpTagStringListLangAlt(const char* xmpTagName, const KExiv2::AltLangMap& values, 
+bool KExiv2::setXmpTagStringListLangAlt(const char* xmpTagName, const KExiv2::AltLangMap& values,
                                         bool setProgramName) const
 {
 #ifdef _XMP_SUPPORT_
@@ -407,6 +444,12 @@ bool KExiv2::setXmpTagStringListLangAlt(const char* xmpTagName, const KExiv2::Al
         d->printExiv2ExceptionError("Cannot set Xmp tag string lang-alt into image using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(values);
+    Q_UNUSED(setProgramName);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -448,12 +491,18 @@ QString KExiv2::getXmpTagStringLangAlt(const char* xmpTagName, const QString& la
                                     .arg(xmpTagName), e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(langAlt);
+    Q_UNUSED(escapeCR);
+
 #endif // _XMP_SUPPORT_
 
     return QString();
 }
 
-bool KExiv2::setXmpTagStringLangAlt(const char* xmpTagName, const QString& value, 
+bool KExiv2::setXmpTagStringLangAlt(const char* xmpTagName, const QString& value,
                                     const QString& langAlt, bool setProgramName) const
 {
 #ifdef _XMP_SUPPORT_
@@ -465,7 +514,7 @@ bool KExiv2::setXmpTagStringLangAlt(const char* xmpTagName, const QString& value
     {
         QString language("x-default"); // default alternative language.
 
-        if (!langAlt.isEmpty()) 
+        if (!langAlt.isEmpty())
             language = langAlt;
 
         QString txtLangAlt = QString("lang=%1 %2").arg(language).arg(value);
@@ -499,6 +548,13 @@ bool KExiv2::setXmpTagStringLangAlt(const char* xmpTagName, const QString& value
         d->printExiv2ExceptionError("Cannot set Xmp tag string lang-alt into image using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(value);
+    Q_UNUSED(langAlt);
+    Q_UNUSED(setProgramName);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -542,6 +598,11 @@ QStringList KExiv2::getXmpTagStringSeq(const char* xmpTagName, bool escapeCR) co
                                     .arg(xmpTagName), e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(escapeCR);
+
 #endif // _XMP_SUPPORT_
 
     return QStringList();
@@ -580,6 +641,12 @@ bool KExiv2::setXmpTagStringSeq(const char* xmpTagName, const QStringList& seq,
         d->printExiv2ExceptionError("Cannot set Xmp tag string Seq into image using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(seq);
+    Q_UNUSED(setProgramName);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -622,6 +689,11 @@ QStringList KExiv2::getXmpTagStringBag(const char* xmpTagName, bool escapeCR) co
                                     .arg(xmpTagName), e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(escapeCR);
+
 #endif // _XMP_SUPPORT_
 
     return QStringList();
@@ -660,6 +732,12 @@ bool KExiv2::setXmpTagStringBag(const char* xmpTagName, const QStringList& bag,
         d->printExiv2ExceptionError("Cannot set Xmp tag string Bag into image using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(bag);
+    Q_UNUSED(setProgramName);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -668,8 +746,6 @@ bool KExiv2::setXmpTagStringBag(const char* xmpTagName, const QStringList& bag,
 bool KExiv2::addToXmpTagStringBag(const char* xmpTagName, const QStringList& entriesToAdd,
                                      bool setProgramName) const
 {
-//#ifdef _XMP_SUPPORT_
-
     if (!setProgramId(setProgramName))
         return false;
 
@@ -686,16 +762,12 @@ bool KExiv2::addToXmpTagStringBag(const char* xmpTagName, const QStringList& ent
     if (setXmpTagStringBag(xmpTagName, newEntries, false))
         return true;
 
-//#endif // _XMP_SUPPORT_
-
     return false;
 }
 
 bool KExiv2::removeFromXmpTagStringBag(const char* xmpTagName, const QStringList& entriesToRemove,
                                        bool setProgramName) const
 {
-//#ifdef _XMP_SUPPORT_
-
     if (!setProgramId(setProgramName))
         return false;
 
@@ -712,8 +784,6 @@ bool KExiv2::removeFromXmpTagStringBag(const char* xmpTagName, const QStringList
     if (setXmpTagStringBag(xmpTagName, newEntries, false))
         return true;
 
-//#endif // _XMP_SUPPORT_
-
     return false;
 }
 
@@ -801,7 +871,7 @@ QVariant KExiv2::getXmpTagVariant(const char* xmpTagName, bool rationalAsListOfI
                     QMap<QString, QVariant> map;
                     // access the ValueType std::map< std::string, std::string>
                     Exiv2::LangAltValue::ValueType::const_iterator i;
-                    for (i = value.value_.begin(); i != value.value_.end(); ++i) 
+                    for (i = value.value_.begin(); i != value.value_.end(); ++i)
                     {
                         map[QString::fromUtf8(i->first.c_str())] = QString::fromUtf8(i->second.c_str());
                     }
@@ -818,6 +888,12 @@ QVariant KExiv2::getXmpTagVariant(const char* xmpTagName, bool rationalAsListOfI
                                     .arg(xmpTagName), e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(rationalAsListOfInts);
+    Q_UNUSED(stringEscapeCR);
+
 #endif // _XMP_SUPPORT_
 
     return QVariant();
@@ -839,6 +915,11 @@ bool KExiv2::registerXmpNameSpace(const QString& uri, const QString& prefix)
         KExiv2Priv::printExiv2ExceptionError("Cannot register a new Xmp namespace using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(uri);
+    Q_UNUSED(prefix);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -860,6 +941,10 @@ bool KExiv2::unregisterXmpNameSpace(const QString& uri)
         KExiv2Priv::printExiv2ExceptionError("Cannot unregister a new Xmp namespace using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(uri);
+
 #endif // _XMP_SUPPORT_
 
     return false;
@@ -887,6 +972,11 @@ bool KExiv2::removeXmpTag(const char* xmpTagName, bool setProgramName) const
         d->printExiv2ExceptionError("Cannot remove Xmp tag using Exiv2 ", e);
     }
 
+#else
+
+    Q_UNUSED(xmpTagName);
+    Q_UNUSED(setProgramName);
+
 #endif // _XMP_SUPPORT_
 
     return false;
