@@ -256,7 +256,7 @@ m_cliPresentation(false), m_embedMode(detectEmbedMode(parentWidget, parent, args
     // we need an instance
     setComponentData(okularPartFactory::componentData());
 
-    GuiUtils::setIconLoader( iconLoader() );
+    GuiUtils::addIconLoader( iconLoader() );
 
     m_sidebar = new Sidebar( parentWidget );
     setWidget( m_sidebar );
@@ -623,6 +623,7 @@ m_cliPresentation(false), m_embedMode(detectEmbedMode(parentWidget, parent, args
 
 Part::~Part()
 {
+    GuiUtils::removeIconLoader( iconLoader() );
     m_document->removeObserver( this );
 
     if ( m_document->isOpened() )
@@ -882,7 +883,7 @@ bool Part::slotImportPSFile()
         m_temporaryLocalFile = tf.fileName();
         tf.close();
 
-        setLocalFilePath( url.path() );
+        setLocalFilePath( url.toLocalFile() );
         QStringList args;
         QProcess *p = new QProcess();
         args << url.toLocalFile() << m_temporaryLocalFile;
@@ -900,17 +901,21 @@ bool Part::slotImportPSFile()
 bool Part::openFile()
 {
     KMimeType::Ptr mime;
+    QString fileNameToOpen = localFilePath();
+    const bool isstdin = url().isLocalFile() && url().fileName( KUrl::ObeyTrailingSlash ) == QLatin1String( "-" );
+    const QFileInfo fileInfo( fileNameToOpen );
+    if ( !isstdin && !fileInfo.exists() )
+        return false;
     if ( !arguments().mimeType().isEmpty() )
     {
         mime = KMimeType::mimeType( arguments().mimeType() );
     }
     if ( !mime )
     {
-        mime = KMimeType::findByPath( localFilePath() );
+        mime = KMimeType::findByPath( fileNameToOpen );
     }
     bool isCompressedFile = false;
     bool uncompressOk = true;
-    QString fileNameToOpen = localFilePath();
     QString compressedMime = compressedMimeFor( mime->name() );
     if ( compressedMime.isEmpty() )
         compressedMime = compressedMimeFor( mime->parentMimeType() );
@@ -992,7 +997,9 @@ bool Part::openFile()
     // if the 'OpenTOC' flag is set, open the TOC
     if ( m_document->metaData( "OpenTOC" ).toBool() && m_sidebar->isItemEnabled( 0 ) )
     {
+        const bool sidebarVisible = m_sidebar->isSidebarVisible();
         m_sidebar->setCurrentIndex( 0 );
+        m_sidebar->setSidebarVisibility( sidebarVisible );
     }
     // if the 'StartFullScreen' flag is set, or the command line flag was
     // specified, start presentation
@@ -1153,7 +1160,11 @@ void Part::slotFileDirty( const QString& path )
     // written to the file.
     if ( path == localFilePath() )
     {
-        m_dirtyHandler->start( 750 );
+        // Only start watching the file in case if it wasn't removed, thus was modified
+        if (QFile::exists(localFilePath()))
+            m_dirtyHandler->start( 750 );
+	else
+            m_fileWasRemoved = true;
     }
     else
     {
@@ -1947,6 +1958,14 @@ void Part::slotPrint()
             printDialog->setEnabledOptions( printDialog->enabledOptions() ^ QAbstractPrintDialog::PrintToFile );
         }
 
+#if QT_VERSION >= KDE_MAKE_VERSION(4,7,0)
+        // Enable the Current Page option in the dialog.
+        if ( m_document->pages() > 1 && currentPage() > 0 )
+        {
+            printDialog->setOption( QAbstractPrintDialog::PrintCurrentPage );
+        }
+#endif
+
         if ( printDialog->exec() )
             doPrint( printer );
         delete printDialog;
@@ -1998,7 +2017,15 @@ void Part::doPrint(QPrinter &printer)
 
     if (!m_document->print(printer))
     {
-        KMessageBox::error(widget(), i18n("Could not print the document. Please report to bugs.kde.org"));
+        const QString error = m_document->printError();
+        if (error.isEmpty())
+        {
+            KMessageBox::error(widget(), i18n("Could not print the document. Unknown error. Please report to bugs.kde.org"));
+        }
+        else
+        {
+            KMessageBox::error(widget(), i18n("Could not print the document. Detailed error is \"%1\". Please report to bugs.kde.org", error));
+        }
     }
 }
 
