@@ -197,7 +197,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     m_topBar->addWidget( spacer );
     m_topBar->addAction( KIcon( "application-exit" ), i18n( "Exit Presentation Mode" ), this, SLOT( close() ) );
     m_topBar->setAutoFillBackground( true );
-    m_topBar->hide();
+    showTopBar( false );
     // change topbar background color
     QPalette p = m_topBar->palette();
     p.setColor( QPalette::Active, QPalette::Button, Qt::gray );
@@ -236,6 +236,9 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     show();
 
     QTimer::singleShot( 0, this, SLOT( slotDelayedEvents() ) );
+
+    // setFocus() so KCursor::setAutoHideCursor() goes into effect if it's enabled
+    setFocus( Qt::OtherFocusReason );
 }
 
 PresentationWidget::~PresentationWidget()
@@ -428,7 +431,7 @@ void PresentationWidget::keyPressEvent( QKeyEvent * e )
             break;
         case Qt::Key_Escape:
             if ( !m_topBar->isHidden() )
-                m_topBar->hide();
+                showTopBar( false );
             else
                 close();
             break;
@@ -482,7 +485,8 @@ void PresentationWidget::mousePressEvent( QMouseEvent * e )
             return;
 
         // handle clicking on top-right overlay
-        if ( m_overlayGeometry.contains( e->pos() ) )
+        if ( !( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::Hidden ) &&
+             m_overlayGeometry.contains( e->pos() ) )
         {
             overlayClick( e->pos() );
             return;
@@ -542,7 +546,7 @@ void PresentationWidget::mouseMoveEvent( QMouseEvent * e )
         // hide a shown bar when exiting the area
         if ( e->y() > ( m_topBar->height() + 1 ) )
         {
-            m_topBar->hide();
+            showTopBar( false );
             setFocus( Qt::OtherFocusReason );
         }
     }
@@ -560,7 +564,7 @@ void PresentationWidget::mouseMoveEvent( QMouseEvent * e )
         {
             // show the bar if reaching top 2 pixels
             if ( e->y() <= 1 )
-                m_topBar->show();
+                showTopBar( true );
             // handle "dragging the wheel" if clicking on its geometry
             else if ( ( QApplication::mouseButtons() & Qt::LeftButton ) && m_overlayGeometry.contains( e->pos() ) )
                 overlayClick( e->pos() );
@@ -665,12 +669,11 @@ void PresentationWidget::leaveEvent( QEvent * e )
 
     if ( !m_topBar->isHidden() )
     {
-        m_topBar->hide();
+        showTopBar( false );
     }
 }
 // </widget events>
 
-
 const Okular::Action * PresentationWidget::getLink( int x, int y, QRect * geometry ) const
 {
     // no links on invalid pages
@@ -847,7 +850,7 @@ void PresentationWidget::generatePage( bool disableTransition )
     }
 
     // update cursor + tooltip
-    if ( Okular::Settings::slidesCursor() != Okular::Settings::EnumSlidesCursor::Hidden )
+    if ( !m_drawingEngine && Okular::Settings::slidesCursor() != Okular::Settings::EnumSlidesCursor::Hidden )
     {
         QPoint p = mapFromGlobal( QCursor::pos() );
         testCursorOnLink( p.x(), p.y() );
@@ -1414,6 +1417,50 @@ void PresentationWidget::allowScreenSaver()
     }
 }
 
+void PresentationWidget::showTopBar( bool show )
+{
+    if ( show )
+    {
+        m_topBar->show();
+
+        // Don't autohide the mouse cursor if it's over the toolbar
+        if ( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::HiddenDelay )
+        {
+            KCursor::setAutoHideCursor( this, false );
+        }
+
+        // Always show a cursor when topBar is visible
+        if ( !m_drawingEngine )
+        {
+                setCursor( QCursor( Qt::ArrowCursor ) );
+        }
+    }
+    else
+    {
+        m_topBar->hide();
+
+        // Reenable autohide if need be when leaving the toolbar
+        if ( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::HiddenDelay )
+        {
+            KCursor::setAutoHideCursor( this, true );
+        }
+
+        // Or hide the cursor again if hidden cursor is enabled
+        else if ( Okular::Settings::slidesCursor() == Okular::Settings::EnumSlidesCursor::Hidden )
+        {
+            // Don't hide the cursor if drawing mode is on
+            if ( !m_drawingEngine )
+            {
+                setCursor( QCursor( Qt::BlankCursor ) );
+            }
+        }
+    }
+
+    // Make sure mouse tracking isn't off after the KCursor::setAutoHideCursor() calls
+    setMouseTracking( true );
+}
+
+
 void PresentationWidget::slotFind()
 {
     if ( !m_searchBar )
